@@ -24,22 +24,21 @@ Attempts to follow the SMTP server RFCs.
 
 """
 
-import time
+from __future__ import absolute_import
 
 import gevent
 from gevent.server import StreamServer
-from gevent.socket import getfqdn
 from gevent import monkey; monkey.patch_all()
 from dns import resolver, reversename
 from dns.exception import DNSException
 
 from slimta.envelope import Envelope
-from slimta.edge import Edge
 from slimta.smtp.server import Server
 from slimta.smtp.reply import unknown_command, bad_sequence
 from slimta.smtp import ConnectionLost, MessageTooBig
 from slimta.queue import QueueError
 from slimta.relay import RelayError
+from . import EdgeServer
 
 __all__ = ['SmtpEdge', 'SmtpValidators']
 
@@ -74,6 +73,8 @@ class SmtpValidators(object):
         #:  * ``auth_result``: The authentication result returned by |Auth|
         #:                     after successful authentication, or ``None`` if
         #:                     the client has not authenticated.
+        #:  * ``envelope``: The |Envelope| being pieced together to send by the
+        #:                  connecting client.
         self.session = session
 
 
@@ -176,8 +177,6 @@ class SmtpSession(object):
         if hasattr(self, '_ptr_lookup_thread'):
             self._ptr_lookup_thread.kill(block=False)
 
-        self.envelope.receiver = getfqdn()
-        self.envelope.timestamp = time.time()
         self.envelope.parse(data)
 
         results = self.handoff(self.envelope)
@@ -193,7 +192,7 @@ class SmtpSession(object):
         self.envelope = None
 
 
-class SmtpEdge(Edge):
+class SmtpEdge(EdgeServer):
     """Class that uses :mod:`slimta.smtp.server` to implement an edge
     service to receive messages.
 
@@ -215,14 +214,17 @@ class SmtpEdge(Edge):
     :param data_timeout: Seconds before the connection times out while
                          receiving data. This is a cumulative timeout that
                          is not tricked by the client sending data.
+    :param hostname: String identifying the local machine. See |Edge| for more
+                     details.
 
     """
 
     def __init__(self, listener, queue, pool=None, max_size=None,
                        validator_class=None, auth_class=None,
                        tls=None, tls_immediately=False,
-                       command_timeout=None, data_timeout=None):
-        super(SmtpEdge, self).__init__(listener, queue, pool)
+                       command_timeout=None, data_timeout=None,
+                       hostname=None):
+        super(SmtpEdge, self).__init__(listener, queue, pool, hostname)
         self.max_size = max_size
         self.command_timeout = command_timeout
         self.data_timeout = data_timeout
